@@ -1,4 +1,25 @@
+"""
+## Amazon Inspector Construct Library
+
+<!--BEGIN STABILITY BANNER-->---
+
+
+![Stability: Experimental](https://img.shields.io/badge/stability-Experimental-important.svg?style=for-the-badge)
+
+> **This is a *developer preview* (public beta) module. Releases might lack important features and might have
+> future breaking changes.**
+>
+> This API is still under active development and subject to non-backward
+> compatible changes or removal in any future version. Use of the API is not recommended in production
+> environments. Experimental APIs are not subject to the Semantic Versioning model.
+
+---
+<!--END STABILITY BANNER-->
+
+This module is part of the [AWS Cloud Development Kit](https://github.com/aws/aws-cdk) project.
+"""
 import abc
+import builtins
 import datetime
 import enum
 import typing
@@ -7,10 +28,12 @@ import jsii
 import jsii.compat
 import publication
 
-from jsii.python import classproperty
-
 import aws_cdk.core
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-inspector", "1.8.0", __name__, "aws-inspector@1.8.0.jsii.tgz")
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-inspector", "1.20.0", __name__, "aws-inspector@1.20.0.jsii.tgz")
+
+
+@jsii.implements(aws_cdk.core.IInspectable)
 class CfnAssessmentTarget(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-inspector.CfnAssessmentTarget"):
     """A CloudFormation ``AWS::Inspector::AssessmentTarget``.
 
@@ -24,7 +47,6 @@ class CfnAssessmentTarget(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsi
 
         :param scope: - scope in which this resource is defined.
         :param id: - scoped id of the resource.
-        :param props: - resource properties.
         :param assessment_target_name: ``AWS::Inspector::AssessmentTarget.AssessmentTargetName``.
         :param resource_group_arn: ``AWS::Inspector::AssessmentTarget.ResourceGroupArn``.
         """
@@ -32,6 +54,17 @@ class CfnAssessmentTarget(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsi
 
         jsii.create(CfnAssessmentTarget, self, [scope, id, props])
 
+    @jsii.member(jsii_name="inspect")
+    def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
+        """Examines the CloudFormation resource and discloses attributes.
+
+        :param inspector: - tree inspector to collect and process attributes.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "inspect", [inspector])
+
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
         """
@@ -39,13 +72,13 @@ class CfnAssessmentTarget(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsi
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @classproperty
+    @jsii.python.classproperty
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
     def CFN_RESOURCE_TYPE_NAME(cls) -> str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @property
+    @builtins.property
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> str:
         """
@@ -54,12 +87,12 @@ class CfnAssessmentTarget(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsi
         """
         return jsii.get(self, "attrArn")
 
-    @property
+    @builtins.property
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[str,typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @property
+    @builtins.property
     @jsii.member(jsii_name="assessmentTargetName")
     def assessment_target_name(self) -> typing.Optional[str]:
         """``AWS::Inspector::AssessmentTarget.AssessmentTargetName``.
@@ -71,9 +104,9 @@ class CfnAssessmentTarget(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsi
 
     @assessment_target_name.setter
     def assessment_target_name(self, value: typing.Optional[str]):
-        return jsii.set(self, "assessmentTargetName", value)
+        jsii.set(self, "assessmentTargetName", value)
 
-    @property
+    @builtins.property
     @jsii.member(jsii_name="resourceGroupArn")
     def resource_group_arn(self) -> typing.Optional[str]:
         """``AWS::Inspector::AssessmentTarget.ResourceGroupArn``.
@@ -85,7 +118,7 @@ class CfnAssessmentTarget(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsi
 
     @resource_group_arn.setter
     def resource_group_arn(self, value: typing.Optional[str]):
-        return jsii.set(self, "resourceGroupArn", value)
+        jsii.set(self, "resourceGroupArn", value)
 
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-inspector.CfnAssessmentTargetProps", jsii_struct_bases=[], name_mapping={'assessment_target_name': 'assessmentTargetName', 'resource_group_arn': 'resourceGroupArn'})
@@ -104,7 +137,7 @@ class CfnAssessmentTargetProps():
         if assessment_target_name is not None: self._values["assessment_target_name"] = assessment_target_name
         if resource_group_arn is not None: self._values["resource_group_arn"] = resource_group_arn
 
-    @property
+    @builtins.property
     def assessment_target_name(self) -> typing.Optional[str]:
         """``AWS::Inspector::AssessmentTarget.AssessmentTargetName``.
 
@@ -113,7 +146,7 @@ class CfnAssessmentTargetProps():
         """
         return self._values.get('assessment_target_name')
 
-    @property
+    @builtins.property
     def resource_group_arn(self) -> typing.Optional[str]:
         """``AWS::Inspector::AssessmentTarget.ResourceGroupArn``.
 
@@ -132,6 +165,7 @@ class CfnAssessmentTargetProps():
         return 'CfnAssessmentTargetProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
+@jsii.implements(aws_cdk.core.IInspectable)
 class CfnAssessmentTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-inspector.CfnAssessmentTemplate"):
     """A CloudFormation ``AWS::Inspector::AssessmentTemplate``.
 
@@ -145,7 +179,6 @@ class CfnAssessmentTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, j
 
         :param scope: - scope in which this resource is defined.
         :param id: - scoped id of the resource.
-        :param props: - resource properties.
         :param assessment_target_arn: ``AWS::Inspector::AssessmentTemplate.AssessmentTargetArn``.
         :param duration_in_seconds: ``AWS::Inspector::AssessmentTemplate.DurationInSeconds``.
         :param rules_package_arns: ``AWS::Inspector::AssessmentTemplate.RulesPackageArns``.
@@ -156,6 +189,17 @@ class CfnAssessmentTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, j
 
         jsii.create(CfnAssessmentTemplate, self, [scope, id, props])
 
+    @jsii.member(jsii_name="inspect")
+    def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
+        """Examines the CloudFormation resource and discloses attributes.
+
+        :param inspector: - tree inspector to collect and process attributes.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "inspect", [inspector])
+
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
         """
@@ -163,13 +207,13 @@ class CfnAssessmentTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, j
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @classproperty
+    @jsii.python.classproperty
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
     def CFN_RESOURCE_TYPE_NAME(cls) -> str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @property
+    @builtins.property
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> str:
         """
@@ -178,12 +222,12 @@ class CfnAssessmentTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, j
         """
         return jsii.get(self, "attrArn")
 
-    @property
+    @builtins.property
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[str,typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @property
+    @builtins.property
     @jsii.member(jsii_name="assessmentTargetArn")
     def assessment_target_arn(self) -> str:
         """``AWS::Inspector::AssessmentTemplate.AssessmentTargetArn``.
@@ -195,9 +239,9 @@ class CfnAssessmentTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, j
 
     @assessment_target_arn.setter
     def assessment_target_arn(self, value: str):
-        return jsii.set(self, "assessmentTargetArn", value)
+        jsii.set(self, "assessmentTargetArn", value)
 
-    @property
+    @builtins.property
     @jsii.member(jsii_name="durationInSeconds")
     def duration_in_seconds(self) -> jsii.Number:
         """``AWS::Inspector::AssessmentTemplate.DurationInSeconds``.
@@ -209,9 +253,9 @@ class CfnAssessmentTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, j
 
     @duration_in_seconds.setter
     def duration_in_seconds(self, value: jsii.Number):
-        return jsii.set(self, "durationInSeconds", value)
+        jsii.set(self, "durationInSeconds", value)
 
-    @property
+    @builtins.property
     @jsii.member(jsii_name="rulesPackageArns")
     def rules_package_arns(self) -> typing.List[str]:
         """``AWS::Inspector::AssessmentTemplate.RulesPackageArns``.
@@ -223,9 +267,9 @@ class CfnAssessmentTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, j
 
     @rules_package_arns.setter
     def rules_package_arns(self, value: typing.List[str]):
-        return jsii.set(self, "rulesPackageArns", value)
+        jsii.set(self, "rulesPackageArns", value)
 
-    @property
+    @builtins.property
     @jsii.member(jsii_name="assessmentTemplateName")
     def assessment_template_name(self) -> typing.Optional[str]:
         """``AWS::Inspector::AssessmentTemplate.AssessmentTemplateName``.
@@ -237,9 +281,9 @@ class CfnAssessmentTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, j
 
     @assessment_template_name.setter
     def assessment_template_name(self, value: typing.Optional[str]):
-        return jsii.set(self, "assessmentTemplateName", value)
+        jsii.set(self, "assessmentTemplateName", value)
 
-    @property
+    @builtins.property
     @jsii.member(jsii_name="userAttributesForFindings")
     def user_attributes_for_findings(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]]]:
         """``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
@@ -251,7 +295,7 @@ class CfnAssessmentTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, j
 
     @user_attributes_for_findings.setter
     def user_attributes_for_findings(self, value: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]]]):
-        return jsii.set(self, "userAttributesForFindings", value)
+        jsii.set(self, "userAttributesForFindings", value)
 
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-inspector.CfnAssessmentTemplateProps", jsii_struct_bases=[], name_mapping={'assessment_target_arn': 'assessmentTargetArn', 'duration_in_seconds': 'durationInSeconds', 'rules_package_arns': 'rulesPackageArns', 'assessment_template_name': 'assessmentTemplateName', 'user_attributes_for_findings': 'userAttributesForFindings'})
@@ -276,7 +320,7 @@ class CfnAssessmentTemplateProps():
         if assessment_template_name is not None: self._values["assessment_template_name"] = assessment_template_name
         if user_attributes_for_findings is not None: self._values["user_attributes_for_findings"] = user_attributes_for_findings
 
-    @property
+    @builtins.property
     def assessment_target_arn(self) -> str:
         """``AWS::Inspector::AssessmentTemplate.AssessmentTargetArn``.
 
@@ -285,7 +329,7 @@ class CfnAssessmentTemplateProps():
         """
         return self._values.get('assessment_target_arn')
 
-    @property
+    @builtins.property
     def duration_in_seconds(self) -> jsii.Number:
         """``AWS::Inspector::AssessmentTemplate.DurationInSeconds``.
 
@@ -294,7 +338,7 @@ class CfnAssessmentTemplateProps():
         """
         return self._values.get('duration_in_seconds')
 
-    @property
+    @builtins.property
     def rules_package_arns(self) -> typing.List[str]:
         """``AWS::Inspector::AssessmentTemplate.RulesPackageArns``.
 
@@ -303,7 +347,7 @@ class CfnAssessmentTemplateProps():
         """
         return self._values.get('rules_package_arns')
 
-    @property
+    @builtins.property
     def assessment_template_name(self) -> typing.Optional[str]:
         """``AWS::Inspector::AssessmentTemplate.AssessmentTemplateName``.
 
@@ -312,7 +356,7 @@ class CfnAssessmentTemplateProps():
         """
         return self._values.get('assessment_template_name')
 
-    @property
+    @builtins.property
     def user_attributes_for_findings(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]]]:
         """``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
 
@@ -331,6 +375,7 @@ class CfnAssessmentTemplateProps():
         return 'CfnAssessmentTemplateProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
+@jsii.implements(aws_cdk.core.IInspectable)
 class CfnResourceGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-inspector.CfnResourceGroup"):
     """A CloudFormation ``AWS::Inspector::ResourceGroup``.
 
@@ -344,13 +389,23 @@ class CfnResourceGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_t
 
         :param scope: - scope in which this resource is defined.
         :param id: - scoped id of the resource.
-        :param props: - resource properties.
         :param resource_group_tags: ``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
         """
         props = CfnResourceGroupProps(resource_group_tags=resource_group_tags)
 
         jsii.create(CfnResourceGroup, self, [scope, id, props])
 
+    @jsii.member(jsii_name="inspect")
+    def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
+        """Examines the CloudFormation resource and discloses attributes.
+
+        :param inspector: - tree inspector to collect and process attributes.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "inspect", [inspector])
+
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
         """
@@ -358,13 +413,13 @@ class CfnResourceGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_t
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @classproperty
+    @jsii.python.classproperty
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
     def CFN_RESOURCE_TYPE_NAME(cls) -> str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @property
+    @builtins.property
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> str:
         """
@@ -373,12 +428,12 @@ class CfnResourceGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_t
         """
         return jsii.get(self, "attrArn")
 
-    @property
+    @builtins.property
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[str,typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @property
+    @builtins.property
     @jsii.member(jsii_name="resourceGroupTags")
     def resource_group_tags(self) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]:
         """``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
@@ -390,7 +445,7 @@ class CfnResourceGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_t
 
     @resource_group_tags.setter
     def resource_group_tags(self, value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]):
-        return jsii.set(self, "resourceGroupTags", value)
+        jsii.set(self, "resourceGroupTags", value)
 
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-inspector.CfnResourceGroupProps", jsii_struct_bases=[], name_mapping={'resource_group_tags': 'resourceGroupTags'})
@@ -407,7 +462,7 @@ class CfnResourceGroupProps():
             'resource_group_tags': resource_group_tags,
         }
 
-    @property
+    @builtins.property
     def resource_group_tags(self) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]:
         """``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
 
